# Carnegie Endowment for International Peace

- Follow Carnegie
- Search
- Global Resources

- Research
- Experts
- Programs
- Events
- Topics

## Chasing Egypt’s Economic Tail

- Yezid Sayigh

article January 22, 2016

The Egyptian president’s central role in economic policy making is unlikely to deliver on the intended goals and could exacerbate existing problems—or generate new ones.

Topics Discussed

- Egypt
- Emerging Economies

- On the Military Yezid Sayigh examines the Egyptian military’s revived role in the national economy | عربي
- On Sisi Nathan J. Brown and Yasser El-Shimy discuss the perspective of the Egyptian military

## U.S. Policy Toward Central Asia 3.0

- Eugene Rumer
- , Richard Sokolsky
- , Paul Stronski

paper January 25, 2016

Major geopolitical shifts and internal dynamics are setting the stage for possible increased great-power competition in Central Asia between Russia and China at a time when the region is becoming less hospitable to the projection of U.S. power and to the promotion of democracy.

Topics Discussed

- Central Asia
- China
- Russia

- On Eurasia Eugene Rumer and Paul Stronski offer a baseline assessment for the countries of Eurasia
- From Beijing Shi Zhiqin and Lu Yang discuss how China and regional forums can help Afghanistan recover

## Look Homeward, Democracy Promoter

- Thomas Carothers

Foreign Policy January 28, 2016

The United States’ deficiencies of democratic governance raise questions about its efforts to promote democracy abroad.

Topics Discussed

- Democracy and Governance
- Political Reform

- On Democracy Richard Youngs discusses whether democracy can work for the world’s value voters
- On Democracy Aid Thomas Carothers argues that democracy aid stands at a crossroads

## Governing Cyberspace: A Road Map for Transatlantic Leadership

- Sinan Ülgen

report January 19, 2016

Cybertechnologies are rapidly changing the international landscape, but weak international governance of cyberspace stands in stark contrast to the accelerating pace of challenges.

Topics Discussed

- Cyber
- Security

- On Cyberspace Carnegie’s Cyber Policy Initiative focuses on addressing international cyber policy challenges
- Strategic Europe Sinan Ülgen explains why the digital world needs transatlantic leadership

## Palestine in Flux

- Nathan J. Brown
- , Daniel Nerenberg

paper January 20, 2016

A new generation of grassroots activists is shifting the focus from a two-state solution to developing tactics aimed at improving the Palestinian position. | عربي

Topics Discussed

- Middle East
- Palestine

- On the Oslo Accords Yezid Sayigh examines the implications and shortcomings of the Oslo Accords | عربي
- On Refugees Maha Yahya discusses refugees and the making of an Arab regional disorder | عربي

## Announcing the Launch of Carnegie India

press release January 12, 2016

The Carnegie Endowment for International Peace announced that Carnegie India, its sixth international center, will open in April 2016.

Topics Discussed

- India
- About Carnegie

- On the Launch More on Carnegie India
- On India Experts offer an action agenda for reform in India

## There’s More Volatility to Come in China

- Yukon Huang

Wall Street Journal January 16, 2016

Beijing’s efforts to liberalize its financial markets have become much more complicated, and increased volatility has been the result.

Topics Discussed

- China
- Emerging Economies

- On the Renminbi Yukon Huang discusses the renminbi’s inclusion in the basket of reserve currencies
- On the Chinese Economy Michael Pettis explains the challenges China will face over the coming decade

## The Right Way to Fight Boko Haram

- Sarah Chayes

Defense One January 16, 2016

Nigerian President Muhammadu Buhari should make his anticorruption agenda central to his campaign against Boko Haram.

Topics Discussed

- Sub-Saharan Africa
- Terrorism

- On Corruption Sarah Chayes discusses why corruption threatens global security
- On Oil Sarah Chayes and Sarah Peck examine the political and economic dysfunction known as the “oil curse”

## Shia-Centric State Building and Sunni Rejection in Post-2003 Iraq

- Fanar Haddad

paper December 23, 2015

The clash of visions over the Iraqi state’s identity, legitimacy, and ownership—long predating the U.S.-led invasion of the country in 2003—has been the root cause of political violence in postwar Arab Iraq.

Topics Discussed

- Security
- Society and Culture
- Middle East
- North Africa

- On Sectarianism Alexandra Siegel discusses Sunni-Shia conflict and cooperation in the digital age
- On the Arab Nation-State Yezid Sayigh argues that Arab states can no longer be reconstructed according to past blueprints

Please note...

You are leaving the website for the Carnegie-Tsinghua Center for Global Policy and entering a website for another of Carnegie's global centers.

请注意...

你将离开清华—卡内基中心网站，进入卡内基其他全球中心的网站。